
 * **BD** - Bayesian nonnegative matrix factorization Gibbs sampler [Schmidt2009]_

 * **BMF** - Binary matrix factorization [Zhang2007]_

 * **ICM** - Iterated conditional modes nonnegative matrix factorization [Schmidt2009]_

 * **LFNMF** - Fisher nonnegative matrix factorization for learning local features [Wang2004]_, [Li2001]_

 * **LSNMF** - Alternating nonnegative least squares matrix factorization using projected gradient method for subproblems [Lin2007]_

 * **NMF** - Standard nonnegative matrix factorization with Euclidean / Kullback-Leibler update equations and Frobenius / divergence / connectivity cost functions [Lee2001]_, [Brunet2004]_

 * **NSNMF** - Nonsmooth nonnegative matrix factorization [Montano2006]_

 * **PMF** - Probabilistic nonnegative matrix factorization [Laurberg2008]_, [Hansen2008]_

 * **PSMF** - Probabilistic sparse matrix factorization [Dueck2005]_, [Dueck2004]_, [Srebro2001]_, [Li2007]_

 * **SNMF** - Sparse nonnegative matrix factorization based on alternating nonnegativity constrained least squares [Park2007]_
    
 * **SNMNMF** - Sparse network-regularized multiple nonnegative matrix factorization [Zhang2011]_
 
 * **PMFCC** - Penalized matrix factorization for constrained clustering [FWang2008]_

 * **SepNMF** - Separable nonnegative matrix factorization [Gillis2014]_, [Kumar2013]_, [Tepper2015]_, [Kapralov2016]_
